import time

from iwla import IWLA
from iplugin import IPlugin
from display import *

class IWLADisplayTopVisitors(IPlugin):
    def __init__(self, iwla):
        super(IWLADisplayTopVisitors, self).__init__(iwla)
        self.API_VERSION = 1

    def hook(self):
        hits = self.iwla.getValidVisitors()

        top_bandwidth = [(k,hits[k]['bandwidth']) for k in hits.keys()]
        top_bandwidth = sorted(top_bandwidth, key=lambda t: t[1], reverse=True)
        top_visitors = [hits[h[0]] for h in top_bandwidth[:10]]

        index = self.iwla.getDisplayIndex()
        table = DisplayHTMLBlockTable('Top visitors', ['Host', 'Pages', 'Hits', 'Bandwidth', 'Last seen'])
        for super_hit in top_visitors:
            address = super_hit['remote_addr']
            if self.iwla.getConfValue('display_visitor_ip', False) and\
                    super_hit.get('dns_name_replaced', False):
                address = '%s [%s]' % (address, super_hit['remote_ip'])

            row = [
                address,
                super_hit['viewed_pages'],
                super_hit['viewed_hits'],
                bytesToStr(super_hit['bandwidth']),
                time.asctime(super_hit['last_access'])
                ]
            table.appendRow(row)
        index.appendBlock(table)
